/*-----------------------------------------------------------------*/
/*! 
  \file scscptypes.h
  \brief SCSCP basic types 
  \author  M. Gastineau 
           Astronomie et Systemes Dynamiques, IMCCE, CNRS, Observatoire de Paris. 

   Copyright, 2008,  M. Gastineau, IMCCE-CNRS
   email of the author : gastineau@imcce.fr

  @bug M. GASTINEAU 12/09/08 : update for SCSCP 1.2
*/
/*-----------------------------------------------------------------*/

/*-----------------------------------------------------------------*/
/* License  of this file :
 This file is "dual-licensed", you have to choose one  of the two licenses 
 below to apply on this file.
 
    CeCILL-C
    	The CeCILL-C license is close to the GNU LGPL.
    	( http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html )
 
 or CeCILL v2.0
      The CeCILL license is compatible with the GNU GPL.
      ( http://www.cecill.info/licences/Licence_CeCILL_V2-en.html )
 

This library is governed by the CeCILL-C or the CeCILL license under 
French law and abiding by the rules of distribution of free software.  
You can  use, modify and/ or redistribute the software under the terms 
of the CeCILL-C or CeCILL license as circulated by CEA, CNRS and INRIA  
at the following URL "http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL-C or CeCILL license and that you accept its terms.
*/
/*-----------------------------------------------------------------*/


#ifndef __SCSCPTYPES_H__
#define __SCSCPTYPES_H__


/*-----------------------------------------------------------------*/
/* types */
/*-----------------------------------------------------------------*/

//! string type
typedef char* SCSCP_string;
   
/*! const string type */
typedef const char* const_SCSCP_string;

/*! time limits type */
typedef size_t SCSCP_time;

/*! memory limits type */
typedef size_t SCSCP_memory;


/*! status type */
/*typedef int SCSCP_status;*/
typedef struct
{
 int   m_code;        /*!< code value */
 /*extended attributes  : only for PROCEDURETERMINATED */
 char *m_cdname;      /*!< name of the content dictionnary */
 char *m_symbolname;  /*!< name of the symbol */
 char *m_message;     /*!< message content */
 char *m_fullformattedmessage; /*! full formatted message for strerror */
} SCSCP_status;

/*-----------------------------------------------------------------*/
/*! enumeration of return type */
/*-----------------------------------------------------------------*/
typedef enum
{
 SCSCP_option_return_object, /*!< return the object*/
 SCSCP_option_return_cookie, /*!< return a cookie*/
 SCSCP_option_return_nothing /*!< return nothing*/
} SCSCP_option_return;

/*-----------------------------------------------------------------*/
/*! enumeration of message type*/
/*-----------------------------------------------------------------*/
typedef enum
{
 SCSCP_msgtype_ProcedureTerminated, /*!< message received is procedure terminated */
 SCSCP_msgtype_ProcedureCompleted,  /*!< message received is procedure completed */
 SCSCP_msgtype_ProcedureCall,       /*!< message received is procedure call */
 SCSCP_msgtype_Interrupt            /*!< message received is interrupt */
} SCSCP_msgtype;
 
/*-----------------------------------------------------------------*/
/*! enumeration of encoding type*/
/*-----------------------------------------------------------------*/
typedef enum
{
 SCSCP_encodingtype_XML,            /*!< OpenMath objects are written using XML encoding */
 SCSCP_encodingtype_Binary          /*!< OpenMath objects are written using Binary encoding */
} SCSCP_encodingtype;

/*-----------------------------------------------------------------*/
/*! enumeration of OpenMath nodes */
/*-----------------------------------------------------------------*/
typedef enum
{
 SCSCP_omtype_CONTENT,      /*!< content node only */
 SCSCP_omtype_OMI,          /*!< OMI */
 SCSCP_omtype_OMF,          /*!< OMF  */
 SCSCP_omtype_OMV,          /*!< OMVAR */
 SCSCP_omtype_OMS,          /*!< OMS */
 SCSCP_omtype_OMSTR,        /*!< OMSTR */
 SCSCP_omtype_OMB,          /*!< OMB */
 SCSCP_omtype_OMFOREIGN,    /*!< OMFOREIGN */
 SCSCP_omtype_OMA,          /*!< OMA */
 SCSCP_omtype_OMBIND,       /*!< OMBIND */
 SCSCP_omtype_OMATTR,       /*!< OMATTR */
 SCSCP_omtype_OME,          /*!< OME */
 SCSCP_omtype_OMATP,        /*!< OMATP */
 SCSCP_omtype_OMOBJ,        /*!< OMOBJ */
 SCSCP_omtype_OMBVAR,       /*!< OMBVAR */
 SCSCP_omtype_OMR,          /*!< OMR external */
} SCSCP_omtype;


#endif /*__SCSCPTYPES_H__*/
